summaryrefslogtreecommitdiff
path: root/cmd/cros_ec.c
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/cros_ec.c')
-rw-r--r--cmd/cros_ec.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmd/cros_ec.c b/cmd/cros_ec.c
index 7b60e415b6c..66a5f6d5210 100644
--- a/cmd/cros_ec.c
+++ b/cmd/cros_ec.c
@@ -13,7 +13,7 @@
#include <dm/device-internal.h>
#include <dm/uclass-internal.h>
/* Note: depends on enum ec_current_image */
static const char * const ec_current_image_name[] = {"unknown", "RO", "RW"};
/**
@@ -312,7 +312,7 @@ static int do_cros_ec(struct cmd_tbl *cmdtp, int flag, int argc,
if (ret)
printf("Error: %d\n", ret);
} else if (0 == strcmp("curimage", cmd)) {
- enum ec_current_image image;
+ enum ec_image image;
if (cros_ec_read_current_image(dev, &image)) {
debug("%s: Could not read KBC image\n", __func__);
@@ -13,7 +13,7 @@
#include <dm/device-internal.h>
#include <dm/uclass-internal.h>
-/* Note: depends on enum ec_current_image */
+/* Note: depends on enum ec_image */
static const char * const ec_current_image_name[] = {"unknown", "RO", "RW"};
/**